@@ -137,9 +137,10 @@ def update_table_from_sql(
         cur.execute(update_sql, {bind_name: today}) # type: ignore
     else:
         cur.execute(update_sql)
+    rows_affected = cur.rowcount
     num_rows_new = cur.execute(count_sql).fetchone()[0] # type: ignore
     rows_inserted = num_rows_new - num_rows_old
-    rows_updated = cur.rowcount - 1
+    rows_updated = rows_affected - rows_inserted
     print("inserted", rows_inserted, "new records")
     print("updated", rows_updated, "existing records")
     if enable_logging:
